pub fn decode_frame(frame: &[u8]) -> Result<PacketEnvelope, ProtocolError>Expand description
Helper for decoding a plaintext frame without constructing a custom codec.
pub fn decode_frame(frame: &[u8]) -> Result<PacketEnvelope, ProtocolError>Helper for decoding a plaintext frame without constructing a custom codec.