pub fn encode_frame(packet: &PacketEnvelope) -> Result<Vec<u8>, ProtocolError>Expand description
Helper for encoding a plaintext frame without constructing a custom codec.
pub fn encode_frame(packet: &PacketEnvelope) -> Result<Vec<u8>, ProtocolError>Helper for encoding a plaintext frame without constructing a custom codec.